@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.cpp,v 1.17 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GlobalVar.cpp,v 1.19 2008/05/05 12:43:59 bowkenken Exp $
 ***************************************************************/
 
 #include "GlobalVar.h"
@@ -37,6 +37,8 @@ GuiMessage gGuiMessage;
 GuiStat gGuiStat;
 GuiNum gGuiNum;
 GuiInputString gGuiInpStr;
+SelMbrGraph *gSelMbrGraph;
+WinPos gWinPos[WIN_KIND_MAX_N];
 
 PcgDun gPcgDun;
 
