@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.cpp,v 1.16 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiInputString.cpp,v 1.18 2008/05/02 12:00:35 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -175,6 +175,24 @@ void GuiInputString::newWin()
 			handle_input_string_ok_clicked ),
 			this );
 #endif	// D_GTK
+
+#ifdef D_MFC
+	if( mInpStrWin != NULL )
+		return;
+
+	mInpStrWin = new CInputLineDlg;
+#endif // D_MFC
+
+	// ʸϥɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_INPUT_STRING].get(
+			WIN_KIND_INPUT_STRING,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_INPUT_STRING].set(
+				WIN_KIND_INPUT_STRING,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -196,6 +214,13 @@ void GuiInputString::destroy()
 
 	mWin = NULL;
 #endif	// D_GTK
+
+#ifdef D_MFC
+	if( mInpStrWin == NULL )
+		return;
+
+	mInpStrWin = NULL;
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -243,13 +268,15 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 #endif // D_GTK
 
 #ifdef D_MFC
-	CInputLineDlg dlg;
-	dlg.m_EditDdx = str;
+	if( mInpStrWin == NULL )
+		return;
 
-	INT_PTR res = dlg.DoModal();
+	mInpStrWin->m_EditDdx = str;
+
+	INT_PTR res = mInpStrWin->DoModal();
 
 	if( res == IDOK )
-		set_key_buf_str( dlg.m_EditDdx );
+		set_key_buf_str( mInpStrWin->m_EditDdx );
 	set_key_buf_str( "\n" );
 #endif // D_MFC
 }
