@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.32 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.33 2008/05/02 04:33:03 bowkenken Exp $
 ***************************************************************/
 
 #include	"gmain.h"
@@ -383,6 +383,17 @@ void GuiMenu::newWin()
 		aBtnMenu[n] = &(mMenuWin->m_aBtn[n]);
 	}
 #endif // D_MFC
+
+	// ˥塼ɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_MENU].get(
+			WIN_KIND_MENU,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_MENU].set(
+				WIN_KIND_MENU,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
