@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.cpp,v 1.42 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiMessage.cpp,v 1.44 2008/05/02 12:00:35 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -314,8 +314,19 @@ void GuiMessage::newWin()
 #endif	// D_GTK
 
 #ifdef D_MFC
-	mMessageWin = (void *)1;
+	mMessageWin = &(theApp.m_MesWnd);
 #endif // D_MFC
+
+	// åɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_MESSAGE].get(
+			WIN_KIND_MESSAGE,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_MESSAGE].set(
+				WIN_KIND_MESSAGE,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
