@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.h,v 1.18 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiMessage.h,v 1.20 2008/05/02 12:00:35 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MESSAGE_H
@@ -52,7 +52,6 @@ private:
 
 #ifdef D_GTK
 	gint nPreX, nPreY, nPreW, nPreH;
-	GtkWidget *mMessageWin;
 	GtkWidget *mMessageDrawingArea;
 	GtkWidget *mMessageHScrollBar;
 	GtkWidget *mMessageVScrollBar;
@@ -65,7 +64,6 @@ private:
 #endif // D_GTK
 
 #ifdef D_MFC
-	void *mMessageWin;
 	CClientDC *pDc;
 #endif // D_MFC
 
@@ -81,8 +79,13 @@ public:
 #endif // D_WS
 
 #ifdef D_GTK
+	GtkWidget *mMessageWin;
 #endif // D_GTK
 
+#ifdef D_MFC
+	class CMessageWnd *mMessageWin;
+#endif // D_MFC
+
 	//////// ѥ֥åСؿ ////////
 public:
 
