@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.16 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.18 2008/05/02 12:00:35 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -388,8 +388,19 @@ void GuiNum::newWin()
 #endif	// D_GTK
 
 #ifdef D_MFC
-	mNumWin = (void *)(new CInputNumDlg);
+	mNumWin = new CInputNumDlg;
 #endif // D_MFC
+
+	// ϥɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_INPUT_NUM].get(
+			WIN_KIND_INPUT_NUM,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_INPUT_NUM].set(
+				WIN_KIND_INPUT_NUM,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
