@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.12 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.14 2008/05/02 04:33:03 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -130,6 +130,17 @@ void GuiStat::newWin()
 #ifdef D_MFC
 	mStatWin = &(theApp.m_StatWnd);
 #endif // D_MFC
+
+	// ơɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_STAT].get(
+			WIN_KIND_STAT,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_STAT].set(
+				WIN_KIND_STAT,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -150,22 +161,22 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 	// ġ롦С
 
-	GtkWidget *handleBox = gtk_handle_box_new();
-	gtk_box_pack_start( GTK_BOX( vBox ), handleBox, FALSE, FALSE, 0 );
-	gtk_widget_show( handleBox );
+	handleBox[n] = gtk_handle_box_new();
+	gtk_box_pack_start( GTK_BOX( vBox ), handleBox[n], FALSE, FALSE, 0 );
+	gtk_widget_show( handleBox[n] );
 
-	GtkWidget *toolBar = gtk_toolbar_new();
-	gtk_toolbar_set_orientation( GTK_TOOLBAR( toolBar ),
+	toolBar[n] = gtk_toolbar_new();
+	gtk_toolbar_set_orientation( GTK_TOOLBAR( toolBar[n] ),
 			GTK_ORIENTATION_HORIZONTAL );
-	gtk_toolbar_set_style( GTK_TOOLBAR( toolBar ),
+	gtk_toolbar_set_style( GTK_TOOLBAR( toolBar[n] ),
 			GTK_TOOLBAR_ICONS );
-	gtk_widget_show( toolBar );
+	gtk_widget_show( toolBar[n] );
 
-	gtk_container_add( GTK_CONTAINER( handleBox ), toolBar );
+	gtk_container_add( GTK_CONTAINER( handleBox[n] ), toolBar[n] );
 
-	GtkWidget *vBox2 = gtk_vbox_new( FALSE, 0 );
-	gtk_container_add( GTK_CONTAINER( toolBar ), vBox2 );
-	gtk_widget_show( vBox2 );
+	vBox2[n] = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add( GTK_CONTAINER( toolBar[n] ), vBox2[n] );
+	gtk_widget_show( vBox2[n] );
 
 	// ơܥκ
 
@@ -206,10 +217,12 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 	gtk_widget_show( labelHp[n] );
 	gtk_widget_show( labelMp[n] );
 
-	GtkWidget *hBox1 = gtk_hbox_new( FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( hBox1 ), btnName[n], FALSE, FALSE, 0 );
-	gtk_box_pack_start( GTK_BOX( hBox1 ), labelAct[n], FALSE, FALSE, 0 );
-	gtk_widget_show( hBox1 );
+	hBox1[n] = gtk_hbox_new( FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( hBox1[n] ),
+			btnName[n], FALSE, FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( hBox1[n] ),
+			labelAct[n], FALSE, FALSE, 0 );
+	gtk_widget_show( hBox1[n] );
 
 	// 襨ꥢ HP
 
@@ -255,10 +268,10 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 	//
 
-	gtk_box_pack_start( GTK_BOX( vBox2 ), hBox1, FALSE, TRUE, 0 );
-	gtk_box_pack_start( GTK_BOX( vBox2 ), btnStat[n], FALSE, TRUE, 0 );
-	gtk_box_pack_start( GTK_BOX( vBox2 ), hBoxHp[n], FALSE, TRUE, 0 );
-	gtk_box_pack_start( GTK_BOX( vBox2 ), hBoxMp[n], FALSE, TRUE, 0 );
+	gtk_box_pack_start( GTK_BOX( vBox2[n] ), hBox1[n], FALSE, TRUE, 0 );
+	gtk_box_pack_start( GTK_BOX( vBox2[n] ), btnStat[n], FALSE, TRUE, 0 );
+	gtk_box_pack_start( GTK_BOX( vBox2[n] ), hBoxHp[n], FALSE, TRUE, 0 );
+	gtk_box_pack_start( GTK_BOX( vBox2[n] ), hBoxMp[n], FALSE, TRUE, 0 );
 
 	// ơܥؤΥ٥ȡϥɥ
 
@@ -322,6 +335,9 @@ void GuiStat::redraw( bool flagAdj )
 			"allow-shrink", FALSE,
 			"allow-grow", FALSE,
 			NULL );
+
+	gtk_widget_show( mStatWin );
+	gtk_widget_show( vBox );
 #endif // D_GTK
 
 #ifdef D_MFC
@@ -392,6 +408,14 @@ void GuiStat::draw( long n )
 	gtk_misc_set_alignment( GTK_MISC( labelMp[n] ), 0.0, 0.5 );
 	gtk_label_set_text( GTK_LABEL( labelMp[n] ), (char *)sMp );
 
+	gtk_widget_show( handleBox[n] );
+	gtk_widget_show( toolBar[n] );
+	gtk_widget_show( vBox2[n] );
+	gtk_widget_show( hBox1[n] );
+	gtk_widget_show( btnName[n] );
+	gtk_widget_show( labelAct[n] );
+	gtk_widget_show( btnStat[n] );
+
 	// HP/MP ΥС
 
 	drawHpMp( n, true );
