@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.12 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: Pcg.h,v 1.14 2008/05/08 10:13:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -62,6 +62,14 @@ private:
 	WSDimage *pImage;
 
 public:
+	// ꥹȤμι
+	Pcg *next;
+	// ѥΥХꥨλΨ
+	ratio_t nRatio;
+	// ѥΥХꥨλΨ
+	rate_t nRate;
+	char mjr, mnr;
+
 	// ǽԤκԤ֡ʥߥá
 	long nWaitReadyMSec;
 
@@ -71,6 +79,11 @@ public:
 		nWaitReadyMSec = nWaitReadyMSecDflt;
 
 		pImage = NULL;
+		next = NULL;
+		nRatio = (ratio_t)1;
+		nRate = _100_PERCENT;
+		mjr = FACE_MJR_NULL;
+		mnr = FACE_MNR_NULL;
 	}
 	~Pcg()
 	{
