@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.15 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.18 2008/05/08 10:13:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -173,6 +173,22 @@ PcgTab gPcgTabWallDun[] = {
 	},
 };
 
+PcgTab gPcgTabStatue[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		30,
+		"wall/statue/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabSignboard[] = {
 	{
 		// 
@@ -317,6 +333,38 @@ PcgTab gPcgTabDoorOpenDun[] = {
 	},
 };
 
+PcgTab gPcgTabWindowClose[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"window/close/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
+PcgTab gPcgTabWindowOpen[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"window/open/",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabTrap[] = {
 	{
 		// ̤
@@ -397,13 +445,6 @@ PcgTab gPcgTabTrap[] = {
 };
 
 PcgTab gPcgTabCrsr[] = {
-	{
-		// 
-		MNSTR_KIND_NULL,
-		FACE_MJR_NULL, FACE_MNR_NULL,
-		100,
-		"cursor/",
-	},
 	{
 		// 
 		MNSTR_KIND_NULL,
@@ -438,25 +479,25 @@ PcgTab gPcgTabCrsrSub[] = {
 PcgTab gPcgTabSquare[] = {
 	{
 		MNSTR_KIND_NULL,
-		FACE_MJR_NULL, FACE_MNR_NULL,
+		FACE_MJR_SQUARE, 'N',
 		100,
 		"anchor/north",
 	},
 	{
 		MNSTR_KIND_NULL,
-		FACE_MJR_NULL, FACE_MNR_NULL,
+		FACE_MJR_SQUARE, 'E',
 		100,
 		"anchor/east",
 	},
 	{
 		MNSTR_KIND_NULL,
-		FACE_MJR_NULL, FACE_MNR_NULL,
+		FACE_MJR_SQUARE, 'S',
 		100,
 		"anchor/south",
 	},
 	{
 		MNSTR_KIND_NULL,
-		FACE_MJR_NULL, FACE_MNR_NULL,
+		FACE_MJR_SQUARE, 'W',
 		100,
 		"anchor/west",
 	},
@@ -793,6 +834,12 @@ PcgTab gPcgTabMbrNull = {
 };
 
 PcgTab gPcgTabMnstr[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/",
+	},
 	/*  */
 	/* ɥ饴 */
 	{
