@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelConf.cpp,v 1.10 2008/01/11 09:13:16 bowkenken Exp $
+* $Id: SelConf.cpp,v 1.12 2008/05/09 10:30:25 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -58,6 +58,11 @@ void handle_sel_conf_ok_clicked(
 void handle_sel_conf_cancel_clicked(
 	GtkWidget *widget, gpointer data
 );
+gint handle_sel_conf_d_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+);
+
+void sel_conf_ok_clicked( GtkWidget *data );
 
 #endif // D_GTK
 
@@ -196,6 +201,17 @@ void SelConf::newWin()
 			GTK_SIGNAL_FUNC( handle_sel_conf_cancel_clicked ),
 			NULL );
 #endif // D_GTK
+
+	// 򥦥ɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_SEL_CONF].get(
+			WIN_KIND_SEL_CONF,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_SEL_CONF].set(
+				WIN_KIND_SEL_CONF,
+				&ix, &iy, &iw, &ih, true );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -318,6 +334,12 @@ void SelConf::setListGui()
 		GtkWidget *wListItem;
 		wListItem = gtk_list_item_new_with_label( sTitle );
 		gtk_container_add( GTK_CONTAINER( lsList ), wListItem );
+
+		gtk_signal_connect( GTK_OBJECT( wListItem ),
+				"button_press_event",
+				GTK_SIGNAL_FUNC( handle_sel_conf_d_clicked ),
+				mSelConfWin );
+
 		gtk_widget_show( wListItem );
 #endif // D_GTK
 
@@ -645,19 +667,7 @@ void handle_sel_conf_ok_clicked(
 	GtkWidget *widget, gpointer data
 )
 {
-	if( gSelConf.pGraphConfSel == NULL )
-		return;
-
-	gtk_grab_remove( (GtkWidget *)data );
-	gSelConf.wipe();
-
-#if SEL_CONF_WIN_MODAL
-	gtk_main_quit();
-#endif // SEL_CONF_WIN_MODAL
-
-	// ᥤν
-
-	init_main_sel_conf( gSelConf.pGraphConfSel );
+	sel_conf_ok_clicked( (GtkWidget *)data );
 }
 
 #endif // D_GTK
@@ -680,3 +690,57 @@ void handle_sel_conf_cancel_clicked(
 }
 
 #endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// ꥹȤΥ֥롦å٥Ƚ
+// GtkWidget *widget : ꥹȡƥ
+// GdkEventButton *event : ٥
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+
+gint handle_sel_conf_d_clicked(
+	GtkWidget *widget, GdkEventButton *event, gpointer data
+)
+{
+	if( !GTK_IS_LIST_ITEM( widget ) )
+		return FALSE;
+	if( event->type != GDK_2BUTTON_PRESS )
+		return FALSE;
+	if( event->button != 1 )
+		return FALSE;
+
+	sel_conf_ok_clicked( (GtkWidget *)data );
+
+	return FALSE;
+}
+
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// OK ܥΥå
+// GtkWidget *data : ֤륦ɥ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+
+void sel_conf_ok_clicked( GtkWidget *data )
+{
+	if( gSelConf.pGraphConfSel == NULL )
+		return;
+
+	if( data != NULL )
+		gtk_grab_remove( data );
+	gSelConf.wipe();
+
+#if SEL_CONF_WIN_MODAL
+	gtk_main_quit();
+#endif // SEL_CONF_WIN_MODAL
+
+	// ᥤν
+
+	init_main_sel_conf( gSelConf.pGraphConfSel );
+}
+
+#endif // D_GTK
