@@ -5,10 +5,12 @@ extern "C" {
 #endif
 
 void	init_auto_menu( void );
+void	reset_static_auto_menu( void );
 void	init_auto_mark_all_appoint( void );
 void	init_auto_mark_appoint( long ls_mbr_n );
 void	init_auto_mark_all_mbr( void );
 void	init_auto_mark_mbr( long ls_mbr_n );
+void	init_auto_mark_new_mbr( long ls_mbr_n );
 void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
 void	ver_up_auto_mark_1_1_1( long ls_mbr_n );
 void	ver_up_auto_mark_1_1_3( void );
@@ -21,6 +23,7 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr );
 bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr );
 bool_t	exec_menu_auto_mark_item( mbr_t *mbr );
 bool_t	exec_menu_auto_mark_door( mbr_t *mbr );
+bool_t	exec_menu_auto_mark_trap( mbr_t *mbr );
 bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr );
 char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_edit_init(
@@ -67,6 +70,9 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_arrange_top( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt );
 char	*menu_auto_mark_arrange( long n, long d );
+bool_t	arrange_auto_mark( long n, long d );
+bool_t	arrange_auto_mark_mbr( long ls_mbr_n, long d );
+bool_t	remove_auto_mark_mbr( long ls_mbr_n );
 char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
 char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
