@@ -4,6 +4,10 @@
 extern "C" {
 #endif
 
+void	init_game( void );
+void	reset_static( void );
+void	reset_static_game_main( void );
+void	game_main( void );
 void	init_arg( void );
 void	chk_arg( int argc, char **argv );
 bool_t	chk_opt_num(
@@ -14,8 +18,6 @@ bool_t	chk_opt_flg(
 );
 void	overwrite_arg();
 void	usage( FILE *fp );
-void	init_game( void );
-void	game_main( void );
 void	exit_game( long code );
 void	close_game( long code );
 void	about_game( void );
