@@ -5,12 +5,13 @@ extern "C" {
 #endif
 
 void	init_var_misc_menu( void );
+void	reset_static_misc_menu( void );
 void	init_misc_menu( void );
 char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
 char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
-bool_t	chk_continue_exec_mode( long *c );
+bool_t	chk_continue_exec_mode( long *c, bool_t *p_flg_clr_key_buf );
 bool_t	get_continue_exec_mode( void );
-bool_t	set_continue_exec_mode( void );
+bool_t	toggle_continue_exec_mode( void );
 bool_t	clr_continue_exec_mode( void );
 char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
@@ -26,6 +27,8 @@ char	*cb_menu_show_map_hint( menu_t **pp, menu_t **dflt );
 void	show_map_hint( long x, long y );
 void	show_map_hint_chr( long x, long y );
 void	show_map_hint_obj( long x, long y );
+const char	*get_str_map_hint_chr( long x, long y );
+const char	*get_str_map_hint_obj( long x, long y );
 char	*cb_menu_chr_data( menu_t **pp, menu_t **dflt );
 char	*menu_sel_mbr_data( void );
 long	menu_show_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n );
@@ -38,6 +41,7 @@ void	exec_menu_edit_mbr_data(
 	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
 );
 bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
+void	sel_mbr_graph_file( mbr_t *mbr );
 char	*menu_sel_mnstr_data( void );
 char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
