@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.21 2007/02/21 05:24:44 bowkenken Exp $
+* $Id: imenu.c,v 1.47 2008/05/05 12:43:44 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -33,6 +33,8 @@
 
 /**/
 
+#define	FLAG_CONTINUE_EXEC_KEY_IDLE	0
+
 #define	MENU_LANG_LS_N_PER_PAGE	10
 
 #define	SCROLL_WIDTH	(WIN_MAP_WIDTH / 2)
@@ -54,17 +56,54 @@ static long	g_user_menu_n;
 static char	g_user_menu_name[USER_MENU_MAX_N][MENU_MSG_MAX_LEN + 1];
 static char	g_user_menu_cmd[USER_MENU_MAX_N][MACRO_MAX_LEN + 1];
 
+static long	g_replay_sel_load_n;
+static menu_t	ls_menu_replay_sel_load[MENU_SAVE_LOAD_MAX_N * 2];
+
 /**/
 
 #include	"imenu-tab.h"
 
 /**/
 
+static long	static_cb_menu_wizard_add_turn__turn;
+static long	static_cb_menu_wizard_lev_up__exp;
+
+/**/
+
 void	init_var_misc_menu( void )
 {
 	clr_user_menu();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_misc_menu( void )
+{
+	pos_t	*crsr = get_crsr();
+	party_t *pty = get_party();
+	long	i;
+
+	g_menu_dflt_misc = NULL;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		g_ls_flg_srch[i] = TRUE;
+
+	g_next_pos.kind = NEXT_POS_KIND_SQUARE;
+	g_next_pos.p = &(pty->square);
+	g_next_pos.n = 0;
+	g_next_pos.x = 0;
+	g_next_pos.y = 0;
+	crsr->x = 0;
+	crsr->y = 0;
+
+	/**/
+
+	static_cb_menu_wizard_add_turn__turn = 0;
+	static_cb_menu_wizard_lev_up__exp = +(100 * 100 * 100);
+}
+
 /**/
 
 void	init_misc_menu( void )
@@ -93,23 +132,53 @@ char	*cb_menu_misc( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt )
 {
-	set_continue_exec_mode();
+	toggle_continue_exec_mode();
 
 	return NULL;
 }
 
 /**/
 
-bool_t	chk_continue_exec_mode( void )
+bool_t	chk_continue_exec_mode( long *c, bool_t *p_flg_clr_key_buf )
+{
+#if	FLAG_CONTINUE_EXEC_KEY_IDLE
+	static bool_t	flg_pre_null = TRUE;
+
+	if( !get_continue_exec_mode() )
+		return FALSE;
+
+	if( flg_pre_null )
+		*c = '.';
+	else
+		*c = CMD_KEY_IDLE;
+	flg_pre_null = !flg_pre_null;
+
+	*p_flg_clr_key_buf = TRUE;
+
+	return TRUE;
+#else
+	if( !get_continue_exec_mode() )
+		return FALSE;
+
+	*c = '.';
+	*p_flg_clr_key_buf = TRUE;
+
+	return TRUE;
+#endif
+}
+
+/**/
+
+bool_t	get_continue_exec_mode( void )
 {
 	return g_flg_continue_exec_mode;
 }
 
 /**/
 
-bool_t	set_continue_exec_mode( void )
+bool_t	toggle_continue_exec_mode( void )
 {
-	g_flg_continue_exec_mode = TRUE;
+	g_flg_continue_exec_mode = !g_flg_continue_exec_mode;
 
 	call_gui_map_cont_exec_set(
 			g_flg_continue_exec_mode );
@@ -414,7 +483,30 @@ void	show_map_hint( long x, long y )
 
 void	show_map_hint_chr( long x, long y )
 {
-	dun_t	*dun = get_dun();
+	const char	*s;
+
+	s = get_str_map_hint_chr( x, y );
+	if( (s != NULL) && (s[0] != '\0') )
+		print_msg( FLG_NULL, s );
+}
+
+/**/
+
+void	show_map_hint_obj( long x, long y )
+{
+	const char	*s;
+
+	s = get_str_map_hint_obj( x, y );
+	if( (s != NULL) && (s[0] != '\0') )
+		print_msg( FLG_NULL, s );
+}
+
+/**/
+
+const char	*get_str_map_hint_chr( long x, long y )
+{
+	static char	buf[SCREEN_WIDTH * 2 + 1];
+	dun_t	*dun;
 	char	mjr, mnr;
 	flg_map_t	flg;
 	char	*msg1, *msg2;
@@ -422,16 +514,17 @@ void	show_map_hint_chr( long x, long y )
 	mnstr_t	*mnstr;
 
 	if( !clip_pos( x, y ) )
-		return;
+		return "";
 
+	dun = get_dun();
 	mjr = dun->map.chr.mjr[y][x];
 	mnr = dun->map.chr.mnr[y][x];
 	flg = dun->map.chr.flg[y][x];
 
 	if( !chk_flg( flg, FLG_MAP_CHR_FIND ) )
-		return;
+		return "";
 	if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) )
-		return;
+		return "";
 
 	mbr = get_mbr( x, y );
 	mnstr = get_mnstr( x, y );
@@ -453,19 +546,22 @@ void	show_map_hint_chr( long x, long y )
 	}
 
 	if( msg2 == NULL ){
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_CHR,
+		sprintf( buf, MSG_MAP_HINT_FMT_CHR,
 				x, y, mjr, mnr, msg1 );
 	} else {
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_CHR_SUB,
+		sprintf( buf, MSG_MAP_HINT_FMT_CHR_SUB,
 				x, y, mjr, mnr, msg1, msg2 );
 	}
+
+	return buf;
 }
 
 /**/
 
-void	show_map_hint_obj( long x, long y )
+const char	*get_str_map_hint_obj( long x, long y )
 {
-	dun_t	*dun = get_dun();
+	static char	buf[SCREEN_WIDTH * 2 + 1];
+	dun_t	*dun;
 	char	mjr, mnr;
 	flg_map_t	flg;
 	char	*msg1, *msg2;
@@ -474,14 +570,15 @@ void	show_map_hint_obj( long x, long y )
 	door_t	*door;
 
 	if( !clip_pos( x, y ) )
-		return;
+		return "";
 
+	dun = get_dun();
 	mjr = dun->map.obj.mjr[y][x];
 	mnr = dun->map.obj.mnr[y][x];
 	flg = dun->map.obj.flg[y][x];
 
 	if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) )
-		return;
+		return "";
 
 	item = get_item( x, y );
 	trap = get_trap( x, y );
@@ -509,10 +606,17 @@ void	show_map_hint_obj( long x, long y )
 		msg2 = get_item_mnr_name( item->mjr, item->mnr );
 	} else if( trap != NULL ){
 		msg1 = MSG_MAP_HINT_TRAP;
+		if( trap->flg_chked )
+			if( trap->tab != NULL )
+				msg2 = trap->tab->name;
 	} else if( door != NULL ){
 		if( chk_flg( door->flg, FLG_DOOR_SHOP ) ){
 			msg1 = MSG_MAP_HINT_SHOP;
 			msg2 = get_shop_name( get_shop_n( door->mnr ) );
+		} else if( mnr == FACE_MNR_GATE ){
+			msg1 = MSG_MAP_HINT_GATE;
+		} else if( mnr == FACE_MNR_WINDOW ){
+			msg1 = MSG_MAP_HINT_WINDOW;
 		} else {
 			msg1 = MSG_MAP_HINT_DOOR;
 		}
@@ -523,12 +627,14 @@ void	show_map_hint_obj( long x, long y )
 	}
 
 	if( msg2 == NULL ){
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ,
-				x, y, mjr, mnr, msg1, msg2 );
+		sprintf( buf, MSG_MAP_HINT_FMT_OBJ,
+				x, y, mjr, mnr, msg1 );
 	} else {
-		print_msg( FLG_NULL, MSG_MAP_HINT_FMT_OBJ_SUB,
+		sprintf( buf, MSG_MAP_HINT_FMT_OBJ_SUB,
 				x, y, mjr, mnr, msg1, msg2 );
 	}
+
+	return buf;
 }
 
 /**/
@@ -555,17 +661,19 @@ char	*menu_sel_mbr_data( void )
 	long	sel_mbr_n = get_sel_mbr_n();
 	long	n;
 	long	page_n;
+	data_n_t	data_n;
 
 	if( sel_mbr_n <= -1 )
 		return STR_MENU_ERR;
 
 	n = sel_mbr_n;
 	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
 
 	while( 1 ){
 		long	add;
 
-		add = menu_show_mbr_data( mbr[n], &page_n );
+		add = menu_show_mbr_data( mbr[n], &page_n, &data_n );
 		if( add == 0 )
 			break;
 
@@ -577,27 +685,30 @@ char	*menu_sel_mbr_data( void )
 
 /**/
 
-long	menu_show_mbr_data( mbr_t *mbr, long *page_n )
+long	menu_show_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n )
 {
-	return menu_mbr_data( mbr, page_n, MBR_DATA_EDIT_KIND_SHOW );
+	return menu_mbr_data( mbr, page_n, data_n,
+			MBR_DATA_EDIT_KIND_SHOW );
 }
 
 /**/
 
-long	menu_edit_mbr_data( mbr_t *mbr, long *page_n )
+long	menu_edit_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n )
 {
-	return menu_mbr_data( mbr, page_n, MBR_DATA_EDIT_KIND_EDIT );
+	return menu_mbr_data( mbr, page_n, data_n,
+			MBR_DATA_EDIT_KIND_EDIT );
 }
 
 /**/
 
 long	menu_mbr_data(
-	mbr_t *org_p, long *page_n,
+	mbr_t *org_p, long *page_n, data_n_t *data_n,
 	mbr_data_edit_kind_t edit_kind
 )
 {
 	mbr_t	dst_mbr, *mbr_p;
-	data_n_t	n, prev_n;
+	data_n_t	prev_n;
+	long	mbr_dn, page_dn;
 
 	if( org_p == NULL )
 		return 0;
@@ -605,8 +716,8 @@ long	menu_mbr_data(
 	mbr_p = &dst_mbr;
 	*mbr_p = *org_p;
 
-	n = next_mbr_data( *page_n, DATA_N_NEXT_PAGE, +-0, edit_kind );
-	prev_n = n;
+	*data_n = next_mbr_data( *page_n, *data_n, +-0, edit_kind );
+	prev_n = *data_n;
 
 	draw_mbr_data_all( org_p, mbr_p, *page_n );
 
@@ -614,8 +725,10 @@ long	menu_mbr_data(
 		bool_t	flg_sel, flg_cancel;
 
 		draw_mbr_data( org_p, mbr_p, prev_n, FALSE );
-		draw_mbr_data( org_p, mbr_p, n, TRUE );
-		prev_n = n;
+		draw_mbr_data( org_p, mbr_p, *data_n, TRUE );
+		prev_n = *data_n;
+		mbr_dn = 0;
+		page_dn = 0;
 
 		flg_sel = FALSE;
 		flg_cancel = FALSE;
@@ -635,33 +748,64 @@ long	menu_mbr_data(
 			else
 				flg_sel = TRUE;
 			break;
+		case '/':
+		case 'z':
+			page_dn -= 1;
+			break;
+		case '*':
+		case 'x':
+			page_dn += 1;
+			break;
+		case '-':
+		case 'c':
+			mbr_dn -= 1;
+			break;
+		case '+':
+		case 'v':
+			mbr_dn += 1;
+			break;
 		case CASE_CRSR_LEFT:
-			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
-				return -1;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+			if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+				page_dn -= 1;
+			else
+				mbr_dn -= 1;
 			break;
 		case CASE_CRSR_RIGHT:
-			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
-				return +1;
-			draw_mbr_data_all( org_p, mbr_p, *page_n );
+			if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+				page_dn += 1;
+			else
+				mbr_dn += 1;
 			break;
 		case CASE_CRSR_DOWN:
-			n = next_mbr_data( *page_n, n, +1, edit_kind );
+			*data_n = next_mbr_data( *page_n, *data_n,
+					+1, edit_kind );
 			break;
 		case CASE_CRSR_UP:
-			n = next_mbr_data( *page_n, n, -1, edit_kind );
+			*data_n = next_mbr_data( *page_n, *data_n,
+					-1, edit_kind );
 			break;
 		default:
 			break;
 		}
 
 		if( flg_sel ){
-			draw_mbr_data( org_p, mbr_p, n, FALSE );
-			*page_n += exec_menu_edit_mbr_data( mbr_p, n );
+			draw_mbr_data( org_p, mbr_p, *data_n, FALSE );
+			exec_menu_edit_mbr_data(
+					mbr_p, *data_n,
+					&mbr_dn, &page_dn );
+		}
+		if( mbr_dn != 0 ){
+			if( exec_menu_ask_edit_mbr_data( org_p, mbr_p ) )
+				return mbr_dn;
+			draw_mbr_data_all( org_p, mbr_p, *page_n );
+		}
+		if( page_dn != 0 ){
+			*page_n += page_dn;
+			*page_n += MBR_DATA_PAGE_MAX_N;
 			*page_n %= MBR_DATA_PAGE_MAX_N;
-			n = next_mbr_data( *page_n, n,
+			*data_n = next_mbr_data( *page_n, *data_n,
 					+-0, edit_kind );
-			prev_n = n;
+			prev_n = *data_n;
 			if( edit_kind == MBR_DATA_EDIT_KIND_NEW ){
 				new_mbr_reset( mbr_p );
 				*org_p = *mbr_p;
@@ -680,8 +824,15 @@ long	menu_mbr_data(
 
 /**/
 
-long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
+void	exec_menu_edit_mbr_data(
+	mbr_t *mbr, data_n_t n, long *mbr_dn, long *page_dn
+)
 {
+	item_t	*item_head, *item;
+	equip_kind_t	eq_k;
+	long	item_n;
+	long	i;
+
 	switch( n ){
 	case DATA_N_NAME:
 		print_msg( FLG_MSG_NO_MORE_NEXT, MSG_GETS_MBR_NAME,
@@ -703,16 +854,83 @@ long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
 	case DATA_N_SEX:
 		exec_menu_sex( &(mbr->sex.cur) );
 		break;
+	case DATA_N_GRAPH_FILE:
+		sel_mbr_graph_file( mbr );
+		break;
 	case DATA_N_CLASS:
 		exec_menu_class( &(mbr->class_n) );
 		break;
+
+	case DATA_N_ITEM_00:
+	case DATA_N_ITEM_01:
+	case DATA_N_ITEM_02:
+	case DATA_N_ITEM_03:
+	case DATA_N_ITEM_04:
+	case DATA_N_ITEM_05:
+	case DATA_N_ITEM_06:
+	case DATA_N_ITEM_07:
+	case DATA_N_ITEM_08:
+	case DATA_N_ITEM_09:
+	case DATA_N_ITEM_10:
+	case DATA_N_ITEM_11:
+	case DATA_N_ITEM_12:
+	case DATA_N_ITEM_13:
+	case DATA_N_ITEM_14:
+	case DATA_N_ITEM_15:
+		item_n = n - DATA_N_ITEM_00;
+
+		item_head = get_mbr_item_asgn( mbr );
+		if( item_head == NULL )
+			break;
+
+		item = item_head->next;
+		for( i = 0; i < item_n; i++, item = item->next )
+			if( item == item_head )
+				break;
+
+		if( (i == item_n) && (item != item_head) )
+			chk_item_data( item );
+		break;
+
+	case DATA_N_EQUIP_WIELDING:
+	case DATA_N_EQUIP_SHIELD:
+	case DATA_N_EQUIP_BOW:
+	case DATA_N_EQUIP_ARW:
+	case DATA_N_EQUIP_HEAD:
+	case DATA_N_EQUIP_NECK:
+	case DATA_N_EQUIP_BODY:
+	case DATA_N_EQUIP_ABOUT_BODY:
+	case DATA_N_EQUIP_ARM:
+	case DATA_N_EQUIP_RIGHT_HAND:
+	case DATA_N_EQUIP_LEFT_HAND:
+	case DATA_N_EQUIP_FEET:
+	case DATA_N_EQUIP_LIGHT_SOURCE:
+		item = get_mbr_item_asgn_equip( mbr );
+		if( item == NULL )
+			break;
+
+		eq_k = (equip_kind_t)(EQUIP_KIND_NULL
+				+ (n - DATA_N_EQUIP_WIELDING));
+
+		if( item[eq_k].kind != ITEM_KIND_NULL )
+			chk_item_data( &(item[eq_k]) );
+		break;
+
+	case DATA_N_PREV_PAGE:
+		if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+			*mbr_dn -= 1;
+		else
+			*page_dn -= 1;
+		return;
 	case DATA_N_NEXT_PAGE:
-		return +1;
+		if( MBR_DATA_CHANGE_PAGE_IS_CRSR )
+			*mbr_dn += 1;
+		else
+			*page_dn += 1;
+		return;
 	default:
 		break;
 	}
-
-	return +-0;
 }
 
 /**/
@@ -739,6 +957,21 @@ bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p )
 
 /**/
 
+void	sel_mbr_graph_file( mbr_t *mbr )
+{
+	if( !g_flg_gui ){
+		print_msg( FLG_MSG_WRN, MSG_ERR_CHK_GUI );
+		return;
+	}
+
+	if( call_sel_mbr_graph_begin( mbr ) )
+		get_key_wait_cancel_or_exec( TRUE );
+
+	call_sel_mbr_graph_end();
+}
+
+/**/
+
 char	*menu_sel_mnstr_data( void )
 {
 	pos_t	*crsr = get_crsr();
@@ -1089,6 +1322,18 @@ char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_crsr_move_abs( menu_t **pp, menu_t **dflt )
+{
+	pos_t	pos;
+
+	if( get_key_pos( &pos ) )
+		move_crsr_abs( pos.x, pos.y );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt )
 {
 	chk_scroll( FALSE );
@@ -1272,6 +1517,83 @@ void	jump_crsr( long dx, long dy )
 
 /**/
 
+char	*cb_menu_crsr_scroll( menu_t **pp, menu_t **dflt )
+{
+	switch( (long)((*pp)->arg) ){
+	case 1:
+		crsr_scroll( -1, +1 );
+		break;
+	case 2:
+		crsr_scroll( 0, +1 );
+		break;
+	case 3:
+		crsr_scroll( +1, +1 );
+		break;
+	case 4:
+		crsr_scroll( -1, 0 );
+		break;
+	case 6:
+		crsr_scroll( +1, 0 );
+		break;
+	case 7:
+		crsr_scroll( -1, -1 );
+		break;
+	case 8:
+		crsr_scroll( 0, -1 );
+		break;
+	case 9:
+		crsr_scroll( +1, -1 );
+		break;
+	default:
+		return STR_MENU_ERR;
+	}
+	chk_scroll( TRUE );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+void	crsr_scroll( long dx, long dy )
+{
+	pos_t	*crsr = get_crsr();
+	pos_t	*draw;
+
+	draw = get_map_draw_pos();
+
+	/* X */
+
+	draw->x += dx;
+	crsr->x += dx;
+
+	if( draw->x < 0 )
+		draw->x = 0;
+	if( draw->x > MAP_MAX_X - WIN_MAP_WIDTH )
+		draw->x = MAP_MAX_X - WIN_MAP_WIDTH;
+
+	if( crsr->x < 0 )
+		crsr->x = 0;
+	if( crsr->x > MAP_MAX_X - 1 )
+		crsr->x = MAP_MAX_X - 1;
+
+	/* Y */
+
+	draw->y += dy;
+	crsr->y += dy;
+
+	if( draw->y < 0 )
+		draw->y = 0;
+	if( draw->y > MAP_MAX_Y - WIN_MAP_HEIGHT )
+		draw->y = MAP_MAX_Y - WIN_MAP_HEIGHT;
+
+	if( crsr->y < 0 )
+		crsr->y = 0;
+	if( crsr->y > MAP_MAX_Y - 1 )
+		crsr->y = MAP_MAX_Y - 1;
+
+	redraw_map();
+}
+
 char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt )
 {
 	mbr_t	*mbr;
@@ -1388,6 +1710,7 @@ void	scroll_center( void )
 	draw = get_map_draw_pos();
 
 	/* X */
+
 	if( crsr->x < 0 )
 		crsr->x = 0;
 	if( crsr->x > MAP_MAX_X - 1 )
@@ -1400,6 +1723,7 @@ void	scroll_center( void )
 		draw->x = MAP_MAX_X - WIN_MAP_WIDTH;
 
 	/* Y */
+
 	if( crsr->y < 0 )
 		crsr->y = 0;
 	if( crsr->y > MAP_MAX_Y - 1 )
@@ -2791,6 +3115,52 @@ char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_screen_size_init( menu_t **pp, menu_t **dflt )
+{
+	if( chk_flg_screen_size_auto() )
+		set_chk_on_menu( *pp, "auto" );
+	else
+		set_chk_off_menu( *pp, "auto" );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_screen_size_auto( menu_t **pp, menu_t **dflt )
+{
+	if( chk_flg( (*pp)->flg, FLG_MENU_CHK_ON ) )
+		set_flg_screen_size_auto( TRUE );
+	else if( chk_flg( (*pp)->flg, FLG_MENU_CHK_OFF ) )
+		set_flg_screen_size_auto( FALSE );
+	else
+		return STR_MENU_ERR;
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_screen_size_lines( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	char	*ret;
+
+	n = get_screen_size_lines();
+
+	ret = exec_menu_sel_num( &n,
+			SCREEN_SIZE_MIN_LINES,
+			SCREEN_SIZE_MAX_LINES );
+	if( ret == NULL ){
+		set_screen_size_lines( n );
+		return STR_MENU_CANCEL;
+	}
+
+	return ret;
+}
+
+/**/
+
 char	*cb_menu_vfx( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*p;
@@ -3481,9 +3851,50 @@ char	*cb_menu_func( menu_t **pp, menu_t **dflt )
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt )
 {
 	long	n;
+	char	*str;
+	char	str_ret_m[4 + 1];
+	char	str_ret_j[4 + 1];
+
+	str_ret_m[0] = 'M' - '@';
+	str_ret_m[1] = '\0';
+	str_ret_j[0] = 'J' - '@';
+	str_ret_j[1] = '\0';
 
 	n = (long)((*pp)->arg);
-	set_key_buf_str( get_func( n ) );
+	str = get_func( n );
+
+	/* ˥塼μ¹ */
+
+	do {
+		if( get_flg_chk_menu() )
+			break;
+
+		if( strcmp( str, "\n" ) == 0 )
+			break;
+		if( strcmp( str, "^M" ) == 0 )
+			break;
+		if( strcmp( str, "^J" ) == 0 )
+			break;
+		if( strcmp( str, str_ret_m ) == 0 )
+			break;
+		if( strcmp( str, str_ret_j ) == 0 )
+			break;
+
+		if( strcmp( str, "\033" ) == 0 )
+			break;
+		if( strcmp( str, "^[" ) == 0 )
+			break;
+		if( strcmp( str, "0" ) == 0 )
+			break;
+		if( strcmp( str, "." ) == 0 ){
+			str = "0";
+			break;
+		}
+
+		return NULL;
+	} while( 0 );
+
+	set_key_buf_str( str );
 
 	return NULL;
 }
@@ -4055,6 +4466,188 @@ char	*cb_menu_system( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_command( menu_t **pp, menu_t **dflt )
+{
+	char	cmd[MENU_COMMAND_MAX_LEN + 1];
+
+	gets_line( MENU_COMMAND_KEY_STR, cmd, MENU_COMMAND_MAX_LEN );
+
+	return exec_menu( get_ls_menu_main(),
+			get_menu_dflt_main(), cmd );
+}
+
+/**/
+
+char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+
+	n = menu_replay_sel_load();
+
+	if( n == SAVE_N_SEL )
+		return STR_MENU_CANCEL;
+
+	if( load_game_replay( FALSE, n ) ){
+		reset_all_save( FALSE );
+		party_exit_bar();
+
+		return NULL;
+	}
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt )
+{
+	if( save_game_replay() )
+		return NULL;
+	else
+		return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_replay_debug( menu_t **pp, menu_t **dflt )
+{
+	if( load_game_replay( FALSE, SAVE_N_BUG_REPO ) ){
+		reset_all_save( FALSE );
+		party_exit_bar();
+
+		return NULL;
+	}
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt )
+{
+	if( save_bug_repo_replay() )
+		return NULL;
+	else
+		return STR_MENU_CANCEL;
+}
+
+/**/
+
+long	menu_replay_sel_load( void )
+{
+	menu_t	*ls;
+	menu_t	*dflt;
+	char	key;
+	long	k;
+	char	*ret;
+	long	i;
+
+	ls = ls_menu_replay_sel_load;
+	dflt = NULL;
+	k = 0;
+	key = 'A';
+
+	str_nz_cpy( ls[k].path, "/replay load list", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	for( i = 0; i < MENU_SAVE_LOAD_MAX_N; i++ ){
+		bool_t	flg_exist_data;
+
+		if( (i != 0) && (i % MENU_SAVE_LOAD_N_PER_PAGE == 0) ){
+			key = 'A';
+
+			str_nz_cpy( ls[k].path,
+					"/replay load list/page separator",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			ls[k].msg[0] = '\0';
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		if( i % MENU_SAVE_LOAD_N_PER_PAGE == 0 ){
+			str_nz_cpy( ls[k].path,
+					"/replay load list/title",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<Title>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = '\0';
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_NULL;
+			str_nz_cpy( ls[k].msg, MSG_MENU_REPLAY_LOAD,
+					MENU_MSG_MAX_LEN );
+			ls[k].call_back = NULL;
+			ls[k].arg = NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+
+		sprintf( ls[k].path, "/replay load list/%ld", i );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = key;
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL;
+		flg_exist_data = get_save_load_ttl( ls[k].msg, i,
+				FALSE, TRUE );
+		ls[k].call_back = cb_menu_replay_sel_load;
+		if( flg_exist_data )
+			ls[k].arg = (void *)i;
+		else
+			ls[k].arg = (void *)-1;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		key++;
+	}
+	ls[k].path[0] = '\0';
+
+	g_replay_sel_load_n = -1;
+
+	while( 1 ){
+		ret = exec_menu( ls, dflt, NULL );
+
+		if( ret == NULL ){
+			if( g_replay_sel_load_n <= -1 )
+				continue;
+			else
+				return g_replay_sel_load_n;
+		}
+
+		return SAVE_N_SEL;
+	}
+
+	return SAVE_N_SEL;
+}
+
+/**/
+
+char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt )
+{
+	if( pp == NULL ){
+		g_replay_sel_load_n = -1;
+		return STR_MENU_ERR;
+	}
+
+	g_replay_sel_load_n = (long)((*pp)->arg);
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt )
 {
 	if( g_flg_debug )
@@ -4098,9 +4691,11 @@ char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt )
 char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt )
 {
 	const long	n = 1 * TURN_A_DAY;
-	static long	turn = 0;
+	long	turn;
 	char	*str;
 
+	turn = static_cb_menu_wizard_add_turn__turn;
+
 	str = exec_menu_sel_num( &turn, -n, +n );
 	if( str != NULL )
 		return str;
@@ -4119,10 +4714,12 @@ char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt )
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
 	const long	n = EXP_MAX;
-	static long	exp = +(100 * 100 * 100);
+	long	exp = +(100 * 100 * 100);
 	char	*str;
 	long	i;
 
+	exp = static_cb_menu_wizard_lev_up__exp = +(100 * 100 * 100);
+
 	str = exec_menu_sel_num( &exp, -n, +n );
 	if( str != NULL )
 		return str;
