@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.21 2008/01/31 18:45:02 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.23 2008/05/03 05:51:12 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -81,6 +81,8 @@ int	main_dows( int argc, char **argv )
 	init_game();
 	change_scene( SCENE_N_INIT );
 
+	theApp.InitWin();
+
 	if( g_flg_gui ){
 		if( !g_Dir3d.CreateDevices(
 				theApp.m_pMainFrm->GetViewWnd() ) ){
@@ -126,6 +128,28 @@ void	init_main_sel_conf( void *cnf )
 		exit_game( EXIT_FAILURE );
 }
 
+////////////////////////////////////////////////////////////////
+// ơС˥åɽ
+// const char *s : եޥåʸ
+// ... : ղð
+////////////////////////////////////////////////////////////////
+
+void	printMapStatBar( const char *s, ... )
+{
+	static char	str[SCREEN_WIDTH * 2 + 1];
+	va_list	argptr;
+
+	va_start( argptr, s );
+	vsprintf( str, s, argptr );
+	va_end( argptr );
+
+	if( theApp.m_pMainFrm == NULL )
+		return;
+
+	CStatusBar &bar = theApp.m_pMainFrm->GetStatusBar();
+	bar.SetPaneText( bar.CommandToIndex( ID_SEPARATOR ), str );
+}
+
 ////////////////////////////////////////////////////////////////
 // λ
 // long code : λ
