@@ -8,6 +8,7 @@ int	main( int argc, char **argv );
 void	init_gtk_win( int argc, char **argv );
 void	init_main_sel_conf( GraphConf *cnf );
 void	init_main_win( void );
+void	printMapStatBar( const char *s, ... );
 gint	handle_delete(
 	GtkWidget *widget, GdkEvent *event, gpointer user_data
 );
@@ -20,6 +21,7 @@ gint	handle_map_expose(
 gint	handle_map_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 );
+void	configure_map( void );
 void	handle_map_scroll_changed(
 	GtkAdjustment *adjustment,
 	gpointer user_data
@@ -31,10 +33,19 @@ gint	handle_map_motion_notify(
 void	handle_exec_clicked(
 	GtkWidget *widget, gpointer *data
 );
-void	handle_cont_exec_toggled(
+void	handle_cont_exec_clicked(
 	GtkToggleButton *btn,
 	gpointer user_data
 );
+void	handle_auto_mark_clicked(
+	GtkWidget *widget, gpointer *data
+);
+void	handle_user_menu_clicked(
+	GtkWidget *widget, gpointer *data
+);
+void	handle_spell_clicked(
+	GtkWidget *widget, gpointer *data
+);
 gint	handle_map_button_press(
 	GtkWidget *widget, GdkEventMotion *event
 );
