@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.34 2008/02/12 20:23:25 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.41 2008/05/05 12:43:59 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -51,6 +51,13 @@
 ////////////////////////////////////////////////////////////////
 
 GtkWidget *btnMapExec;
+GtkWidget *btnMapAutoMark;
+GtkWidget *btnMapUserMenu;
+GtkWidget *btnMapSpell;
+
+GtkWidget *statBarMap;
+guint statBarMapContextId;
+guint statBarMapMesId;
 
 guint ghTimer;
 
@@ -149,6 +156,7 @@ void	init_main_sel_conf( GraphConf *cnf )
 	// Ƽ
 
 	gPcgDun.init( cnf );
+	configure_map();
 
 	gtk_timeout_remove( ghTimer );
 	change_scene( SCENE_N_TOWN );
@@ -213,11 +221,14 @@ void	init_main_win( void )
 
 	btnMapExec = gtk_button_new_with_label(
 			MSG_GUI_MAP_EXEC );
-	gMapButtonContExec = gtk_toggle_button_new_with_label(
-			MSG_GUI_MAP_CONT_EXEC );
-
-	gtk_toggle_button_set_active(
-			GTK_TOGGLE_BUTTON( gMapButtonContExec ), FALSE );
+	gMapButtonContExec = gtk_button_new_with_label(
+			MSG_GUI_MAP_CONT_EXEC_OFF );
+	btnMapAutoMark = gtk_button_new_with_label(
+			MSG_GUI_MAP_AUTO_MARK );
+	btnMapUserMenu = gtk_button_new_with_label(
+			MSG_GUI_MAP_USER_MENU );
+	btnMapSpell = gtk_button_new_with_label(
+			MSG_GUI_MAP_SPELL );
 
 	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
 			btnMapExec,
@@ -227,9 +238,24 @@ void	init_main_win( void )
 			gMapButtonContExec,
 			MSG_GUI_MAP_TOOL_TIP_CONT_EXEC,
 			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapAutoMark,
+			MSG_GUI_MAP_TOOL_TIP_AUTO_MARK,
+			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapUserMenu,
+			MSG_GUI_MAP_TOOL_TIP_USER_MENU,
+			NULL );
+	gtk_toolbar_append_widget( GTK_TOOLBAR( toolBar ),
+			btnMapSpell,
+			MSG_GUI_MAP_TOOL_TIP_SPELL,
+			NULL );
 
 	gtk_widget_show( btnMapExec );
 	gtk_widget_show( gMapButtonContExec );
+	gtk_widget_show( btnMapAutoMark );
+	gtk_widget_show( btnMapUserMenu );
+	gtk_widget_show( btnMapSpell );
 
 	// ġ롦СؤΥ٥ȡϥɥ
 
@@ -238,8 +264,20 @@ void	init_main_win( void )
 			GTK_SIGNAL_FUNC( handle_exec_clicked ),
 			NULL );
 	gtk_signal_connect( GTK_OBJECT( gMapButtonContExec ),
-			"toggled",
-			GTK_SIGNAL_FUNC( handle_cont_exec_toggled ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_cont_exec_clicked ),
+			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapAutoMark ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_auto_mark_clicked ),
+			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapUserMenu ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_user_menu_clicked ),
+			NULL );
+	gtk_signal_connect( GTK_OBJECT( btnMapSpell ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_spell_clicked ),
 			NULL );
 
 	// 襨ꥢ
@@ -384,6 +422,23 @@ void	init_main_win( void )
 			0, 0 );
 	gtk_widget_show( gMapVScrollBar );
 
+	// ơС
+
+	statBarMap = gtk_statusbar_new();
+	if( statBarMap == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_statusbar_new()" );
+		exit_game( EXIT_FAILURE );
+	}
+	gtk_box_pack_start( GTK_BOX( vBox ), statBarMap, FALSE, FALSE, 0 );
+	statBarMapContextId = gtk_statusbar_get_context_id(
+			GTK_STATUSBAR( statBarMap ), "Status bar" );
+	gtk_statusbar_set_has_resize_grip(
+			GTK_STATUSBAR( statBarMap ), TRUE );
+	statBarMapMesId = gtk_statusbar_push(
+			GTK_STATUSBAR( statBarMap ),
+			statBarMapContextId, "OK" );
+	gtk_widget_show( statBarMap );
+
 	// ᥤ󡦥ɥɽ
 
 	gtk_widget_show( gMapWin );
@@ -391,10 +446,50 @@ void	init_main_win( void )
 	gtk_drawing_area_size( GTK_DRAWING_AREA( gMapDrawingArea ),
 			MAP_WIN_MIN_WIDTH(),
 			MAP_WIN_MIN_HEIGHT() );
+
+	// ᥤ󡦥ɥκɸ
+
+	long ix, iy, iw, ih;
+	if( gWinPos[WIN_KIND_MAP].get(
+			WIN_KIND_MAP,
+			&ix, &iy, &iw, &ih, true ) ){
+		gWinPos[WIN_KIND_MAP].set(
+				WIN_KIND_MAP,
+				&ix, &iy, &iw, &ih, true );
+	}
+}
+
+////////////////////////////////////////////////////////////////
+// ơС˥åɽ
+// const char *s : եޥåʸ
+// ... : ղð
+////////////////////////////////////////////////////////////////
+
+void	printMapStatBar( const char *s, ... )
+{
+	static char	str[SCREEN_WIDTH * 2 + 1];
+	va_list	argptr;
+
+	va_start( argptr, s );
+	vsprintf( str, s, argptr );
+	va_end( argptr );
+
+	gtk_statusbar_remove(
+			GTK_STATUSBAR( statBarMap ),
+			statBarMapContextId,
+			statBarMapMesId );
+
+	statBarMapMesId = gtk_statusbar_push(
+			GTK_STATUSBAR( statBarMap ),
+			statBarMapContextId,
+			str );
 }
 
 ////////////////////////////////////////////////////////////////
 // GTK+ νλ׵Υϥɥ
+// GtkWidget *widget : ᥤ󡦥ɥ
+// GdkEvent *event : ٥
+// gpointer user_data : ϿϤ줿ǡ
 ////////////////////////////////////////////////////////////////
 
 gint	handle_delete(
@@ -408,6 +503,8 @@ gint	handle_delete(
 
 ////////////////////////////////////////////////////////////////
 // GTK+ νλΥϥɥ
+// GtkWidget *widget : ᥤ󡦥ɥ
+// gpointer user_data : ϿϤ줿ǡ
 ////////////////////////////////////////////////////////////////
 
 void	handle_destroy(
@@ -462,6 +559,17 @@ gint	handle_map_expose(
 gint	handle_map_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 )
+{
+	configure_map();
+
+	return TRUE;
+}
+
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥѹ
+////////////////////////////////////////////////////////////////
+
+void	configure_map( void )
 {
 	// ʿ롦СĴ
 
@@ -492,10 +600,6 @@ gint	handle_map_configure(
 		vAdj->value = vAdj->upper - h;
 
 	gtk_adjustment_changed( vAdj );
-
-	//
-
-	return TRUE;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -556,6 +660,9 @@ gint	handle_map_draw( gpointer p )
 #else
 	if( chk_scene_group( SCENE_GROUP_N_TITLE ) )
 		gPcgDun.drawTitle();
+	if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) )
+		if( gSelMbrGraph != NULL )
+			gSelMbrGraph->redraw();
 
 	GtkWidget *drawingArea = (GtkWidget *)p;
 	GdkRectangle rect;
@@ -616,19 +723,51 @@ void	handle_exec_clicked(
 // gpointer user_data : ϿϤ줿ǡ
 ////////////////////////////////////////////////////////////////
 
-void	handle_cont_exec_toggled(
+void	handle_cont_exec_clicked(
 	GtkToggleButton *btn,
 	gpointer user_data
 )
 {
-	bool_t flg = gtk_toggle_button_get_active( btn );
-	if( !flg == !get_continue_exec_mode() )
-		return;
+	gKey.setChar( CMD_KEY_CONT_EXEC, FALSE );
+}
 
-	if( gtk_toggle_button_get_active( btn ) )
-		gKey.setChar( ',', FALSE );
-	else
-		gKey.setChar( '|', FALSE );
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_auto_mark_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	gKey.setChar( '/', TRUE );
+}
+
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_user_menu_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	gKey.setChar( '*', TRUE );
+}
+
+////////////////////////////////////////////////////////////////
+// ޥåסɥΥܥΥå٥Ƚ
+// GtkWidget *widget : ܥ
+// gpointer data : ϿϤ줿ǡ
+////////////////////////////////////////////////////////////////
+
+void	handle_spell_clicked(
+	GtkWidget *widget, gpointer *data
+)
+{
+	gKey.setChar( '-', TRUE );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -676,6 +815,24 @@ gint	handle_map_button_press(
 	if( state & GDK_BUTTON5_MASK )
 		gMouseMotion.begin( MouseMotion::nMouseButton4, x, y );
 
+	if( event->type == GDK_2BUTTON_PRESS ){
+		if( state & GDK_BUTTON1_MASK )
+			gMouseMotion.doubleClick(
+					MouseMotion::nMouseButton0, x, y );
+		if( state & GDK_BUTTON2_MASK )
+			gMouseMotion.doubleClick(
+					MouseMotion::nMouseButton1, x, y );
+		if( state & GDK_BUTTON3_MASK )
+			gMouseMotion.doubleClick(
+					MouseMotion::nMouseButton2, x, y );
+		if( state & GDK_BUTTON4_MASK )
+			gMouseMotion.doubleClick(
+					MouseMotion::nMouseButton3, x, y );
+		if( state & GDK_BUTTON5_MASK )
+			gMouseMotion.doubleClick(
+					MouseMotion::nMouseButton4, x, y );
+	}
+
 	return TRUE;
 }
 
