@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.202 2008/02/14 23:41:53 bowkenken Exp $
+* $Id: menu.c,v 1.206 2008/04/18 23:05:34 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -95,6 +95,7 @@ static func_short_key_t
 		g_ls_func_short_key[FUNC_KEY_MAX + 1] = {
 	{ NULL, NULL },	/* NULL */
 
+/* ե󥯥󡦥 */
 	{ NULL, NULL },	/* F1 */
 	{ NULL, NULL },	/* F2 */
 	{ NULL, NULL },	/* F3 */
@@ -116,8 +117,9 @@ static func_short_key_t
 	{ NULL, NULL },	/* F19 */
 	{ NULL, NULL },	/* F20 */
 
-	{ NULL, "\n" },	/* F21 */
-	{ NULL, "+" },	/* F22 */
+/* ޥå */
+	{ NULL, "+" },	/* F21 */
+	{ NULL, NULL },	/* F22 */
 	{ NULL, "." },	/* F23 */
 	{ NULL, NULL },	/* F24 */
 	{ NULL, NULL },	/* F25 */
@@ -127,8 +129,9 @@ static func_short_key_t
 	{ NULL, NULL },	/* F29 */
 	{ NULL, NULL },	/* F30 */
 
-	{ NULL, "+" },	/* F31 */
-	{ NULL, "," },	/* F32 */
+/* ޥ֥롦å */
+	{ NULL, "\n" },	/* F31 */
+	{ NULL, NULL },	/* F32 */
 	{ NULL, NULL },	/* F33 */
 	{ NULL, NULL },	/* F34 */
 	{ NULL, NULL },	/* F35 */
@@ -138,16 +141,51 @@ static func_short_key_t
 	{ NULL, NULL },	/* F39 */
 	{ NULL, NULL },	/* F40 */
 
-	{ NULL, "/" },	/* F41 */
-	{ NULL, "*" },	/* F42 */
-	{ NULL, "-" },	/* F43 */
-	{ NULL, "+" },	/* F44 */
+/* ޥξå */
+	{ NULL, "+" },	/* F41 */
+	{ NULL, "," },	/* F42 */
+	{ NULL, NULL },	/* F43 */
+	{ NULL, NULL },	/* F44 */
 	{ NULL, NULL },	/* F45 */
 	{ NULL, NULL },	/* F46 */
 	{ NULL, NULL },	/* F47 */
 	{ NULL, NULL },	/* F48 */
 	{ NULL, NULL },	/* F49 */
 	{ NULL, NULL },	/* F50 */
+
+/* ޥץ쥹 */
+	{ NULL, NULL },	/* F51 */
+	{ NULL, NULL },	/* F52 */
+	{ NULL, "," },	/* F53 */
+	{ NULL, NULL },	/* F54 */
+	{ NULL, NULL },	/* F55 */
+	{ NULL, NULL },	/* F56 */
+	{ NULL, NULL },	/* F57 */
+	{ NULL, NULL },	/* F58 */
+	{ NULL, NULL },	/* F59 */
+	{ NULL, NULL },	/* F60 */
+/* ޥ꡼ */
+	{ NULL, NULL },	/* F61 */
+	{ NULL, NULL },	/* F62 */
+	{ NULL, "0" },	/* F63 */
+	{ NULL, NULL },	/* F64 */
+	{ NULL, NULL },	/* F65 */
+	{ NULL, NULL },	/* F66 */
+	{ NULL, NULL },	/* F67 */
+	{ NULL, NULL },	/* F68 */
+	{ NULL, NULL },	/* F69 */
+	{ NULL, NULL },	/* F70 */
+/* ޥ⡼ */
+	{ NULL, "/" },	/* F71 */
+	{ NULL, "*" },	/* F72 */
+	{ NULL, "-" },	/* F73 */
+	{ NULL, "+" },	/* F74 */
+	{ NULL, NULL },	/* F75 */
+	{ NULL, NULL },	/* F76 */
+	{ NULL, NULL },	/* F77 */
+	{ NULL, NULL },	/* F78 */
+	{ NULL, NULL },	/* F79 */
+	{ NULL, NULL },	/* F80 */
 };
 
 static bool_t	g_flg_dup_short_key[256];
@@ -190,6 +228,14 @@ void	init_menu( void )
 	init_ls_menu_func();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_menu( void )
+{
+}
+
 /**/
 
 void	init_ls_menu_func( void )
