@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.94 2007/01/25 15:47:33 bowkenken Exp $
+* $Id: request.c,v 1.98 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -44,9 +44,6 @@
 # define	FLG_DEBUG_REQUEST	0
 #endif
 
-/* Υޥ */
-#define	BAR_MASTER_SEX	MALE
-
 /* Υ˥塼ꥹȤΥڡιܿ */
 #define	MENU_REQUEST_N_PER_PAGE	10
 
@@ -138,6 +135,14 @@ void	init_request( void )
 		g_request[i].kind = REQUEST_KIND_NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_request( void )
+{
+}
+
 /***************************************************************
 * Ϥ
 ***************************************************************/
@@ -1971,15 +1976,15 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	if( chr == NULL )
 		return;
 
-	req = chr->work.request;
-	if( req == NULL )
-		return;
-
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_TOUR_GUIDE, FALSE );
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_EXTERMINATE, TRUE );
 
+	req = chr->work.request;
+	if( req == NULL )
+		return;
+
 	switch( req->kind ){
 	case REQUEST_KIND_NULL:
 		break;
@@ -2210,6 +2215,8 @@ void	close_all_request( chr_kind_t chr_kind )
 bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 {
 	party_t	*pty = get_party();
+	sex_t	master_sex;
+	const char	*master_name;
 	long	i;
 
 	if( req == NULL )
@@ -2248,14 +2255,19 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 
 	not_join_all_client( req, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	/* åɽ */
+
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_1_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_1_MALE );
 
 	add_party_gold( req->prize );
 	exp_party( req->exp, FALSE, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_2_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_2_MALE );
 
@@ -2786,6 +2798,8 @@ char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt )
 bool_t	ask_contract_request( request_t *req )
 {
 	ask_t	ask;
+	sex_t	master_sex;
+	const char	*master_name;
 
 	if( req == NULL )
 		return FALSE;
@@ -2796,7 +2810,9 @@ bool_t	ask_contract_request( request_t *req )
 	if( ask != ASK_YES )
 		return FALSE;
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
@@ -2814,6 +2830,8 @@ bool_t	ask_cancel_request( request_t *req )
 	char	msg[MENU_MSG_MAX_LEN + 1];
 	gold_t	penalty;
 	ask_t	ask;
+	sex_t	master_sex;
+	const char	*master_name;
 
 	if( req == NULL )
 		return FALSE;
@@ -2834,7 +2852,9 @@ bool_t	ask_cancel_request( request_t *req )
 
 	not_join_all_client( req, FALSE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+	master_sex = get_npc_sex_shop( SHOP_N_BAR );
+	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
+	print_words( master_name, master_sex,
 			MSG_WORDS_REQUEST_CANCEL_FEMALE,
 			MSG_WORDS_REQUEST_CANCEL_MALE );
 
