@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.117 2007/12/14 23:24:19 bowkenken Exp $
+* $Id: tmenu.c,v 1.120 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -73,7 +73,11 @@ static menu_t	*g_navi_dflt;
 
 /**/
 
-void	init_tmenu( void )
+static edit_class_t	static_exec_edit_class__n;
+
+/**/
+
+void	init_town_menu( void )
 {
 	party_t	*pty = get_party();
 	mbr_t	**ls_mbr = get_ls_mbr();
@@ -86,6 +90,33 @@ void	init_tmenu( void )
 	g_navi_dflt = NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_town_menu( void )
+{
+	party_t	*pty = get_party();
+	mbr_t	**ls_mbr = get_ls_mbr();
+	long	i;
+
+	g_sel_mbr = pty->mbr[0];
+	g_sel_ls_mbr = ls_mbr[0];
+	g_shop_n = SHOP_N_NULL;
+	g_deal_kind = DEAL_KIND_BUY;
+	g_sel_art = NULL;
+	g_sel_class_n = 0;
+
+	for( i = 0; i < MBR_MAX_N; i++ )
+		g_mbr_order[i] = NULL;
+
+	g_navi_dflt = NULL;
+
+	/**/
+
+	static_exec_edit_class__n = EDIT_CLASS_NEXT;
+}
+
 /**/
 
 char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet )
@@ -2371,11 +2402,13 @@ char	*menu_new_class( long n )
 
 long	exec_edit_class( class_t *org, bool_t flg_new )
 {
-	static edit_class_t	n = EDIT_CLASS_NEXT;
+	edit_class_t	n;
 	edit_class_t	prev_n;
 	class_t	edit, *work;
 	bool_t	flg_sel_add;
 
+	n = static_exec_edit_class__n;
+
 	if( org == NULL )
 		return 0;
 
@@ -2721,15 +2754,31 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 	price = get_price_inn( flg_short );
 
 	flg_pay = TRUE;
-	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
+	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ ){
+		if( chk_flg_or( pty->mbr[mbr_n]->stat, 0
+				| FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD
+				| FLG_STAT_STONE ) ){
+			continue;
+		}
+
 		if( !chk_pay( pty->mbr[mbr_n], price ) )
 			flg_pay = FALSE;
+	}
 
 	if( !flg_pay )
 		return STR_MENU_CANCEL;
 
-	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
+	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ ){
+		if( chk_flg_or( pty->mbr[mbr_n]->stat, 0
+				| FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD
+				| FLG_STAT_STONE ) ){
+			continue;
+		}
+
 		add_chr_gold( pty->mbr[mbr_n], -price );
+	}
 
 	stay_inn( flg_short, FALSE );
 
