@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.129 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: town.c,v 1.133 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -186,18 +186,26 @@
 
 discount_queue_t	g_discount_queue;
 
-/* ϤΤΨ */
+/**/
 
+/* ϤΤΨ */
 #define	MBR_IS_MOLESTED_RATE	((rate_t)10)
 
+/* µܤؤγʤȾ */
+#define	TOWN_STAIRS_R	1
+
 /**/
 
 #define	STR_XPM_COL_NONE	"None"
 
+/***************************************************************/
+
 #include	"town-ptn.xpm"
 #include	"town-tab.h"
 #include	"rumor-tab.h"
 
+/***************************************************************/
+
 static town_ptn_t	town_ptn, town_ptn_trans;
 
 static long	g_morning_glow_n, g_evening_glow_n;
@@ -220,6 +228,16 @@ void	init_town( void )
 
 /**/
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_town( void )
+{
+}
+
+/**/
+
 void	reset_glow( void )
 {
 	g_morning_glow_n = 4;
@@ -506,6 +524,10 @@ void	make_town( void )
 
 	make_fence();
 
+	/* īͼꥻå */
+
+	reset_glow();
+
 	/*  */
 
 	make_streetlamp();
@@ -581,22 +603,34 @@ void	make_town( void )
 void	make_town_ptn( void )
 {
 	dun_t *dun = get_dun();
-	long	i, j;
+	long	x, y;
+	long	i;
 
-	for( i = 0; i < MAP_MAX_Y; i++ )
-		for( j = 0; j < MAP_MAX_X; j++ )
-			make_field_town( &town_ptn, j, i );
+	for( y = 0; y < MAP_MAX_Y; y++ )
+		for( x = 0; x < MAP_MAX_X; x++ )
+			make_field_town( &town_ptn, x, y );
 
-	for( i = 0; i < MAP_MAX_Y; i++ ){
-		for( j = 0; j < MAP_MAX_X; j++ ){
+	x = MAP_DEL_X;
+	y = MAP_DEL_Y;
+	for( i = 0; i < LOOP_MAX_100; i++ ){
+		if( !srch_map_obj( FACE_MJR_STAIRS_DOWN,
+				FACE_MNR_STAIRS_DOWN, &x, &y ) ){
+			break;
+		}
+
+		extend_stairs( x, y );
+	}
+
+	for( y = 0; y < MAP_MAX_Y; y++ ){
+		for( x = 0; x < MAP_MAX_X; x++ ){
 			char	mjr, mnr;
 
-			mjr = dun->map.obj.mjr[i][j];
+			mjr = dun->map.obj.mjr[y][x];
 			if( mjr != FACE_MJR_DOOR_CLOSE )
 				continue;
-			mnr = dun->map.obj.mnr[i][j];
+			mnr = dun->map.obj.mnr[y][x];
 
-			make_door_town( j, i, mnr );
+			make_door_town( x, y, mnr );
 		}
 	}
 }
@@ -671,6 +705,44 @@ void	make_field_town( town_ptn_t *ptn, long x, long y )
 
 /**/
 
+bool_t	extend_stairs( long x, long y )
+{
+	dun_t	*dun = get_dun();
+	char	mjr;
+	long	xr, yr;
+	long	xx, yy;
+
+	if( dun->map.obj.mjr[y][x] != FACE_MJR_STAIRS_UP )
+		if( dun->map.obj.mjr[y][x] != FACE_MJR_STAIRS_DOWN )
+			return FALSE;
+	if( dun->map.obj.mnr[y][x] != FACE_MNR_STAIRS_UP )
+		if( dun->map.obj.mnr[y][x] != FACE_MNR_STAIRS_DOWN )
+			return FALSE;
+
+	mjr = dun->map.obj.mjr[y][x];
+
+	for( yr = -TOWN_STAIRS_R; yr <= +TOWN_STAIRS_R; yr++ ){
+		for( xr = -TOWN_STAIRS_R; xr <= +TOWN_STAIRS_R; xr++ ){
+			xx = x + xr;
+			yy = y + yr;
+			if( !clip_pos( xx, yy ) )
+				continue;
+
+			if( dun->map.obj.mjr[yy][xx] != FACE_MJR_FLOOR )
+				continue;
+			if( dun->map.obj.mnr[yy][xx] != FACE_MNR_FLOOR )
+				continue;
+
+			dun->map.obj.mjr[yy][xx] = mjr;
+			dun->map.obj.mnr[yy][xx] = FACE_MNR_NULL;
+		}
+	}
+
+	return TRUE;
+}
+
+/**/
+
 void	make_streetlamp( void )
 {
 	dun_t	*dun = get_dun();
@@ -1162,10 +1234,9 @@ bool_t	chk_shop_face_ls( void )
 bool_t	appear_party_town( void )
 {
 	dun_t *dun;
-	long	i, j;
-	bool_t	flg_find;
 	party_t	*pty;
 	long	n;
+	long	x, y;
 
 	dun = get_dun();
 	pty = get_party();
@@ -1175,25 +1246,16 @@ bool_t	appear_party_town( void )
 		clr_chr_trgt_act( pty->mbr[n], FALSE );
 	}
 
-	flg_find = FALSE;
-	for( i = 0; i < MAP_MAX_Y; i++ ){
-		for( j = 0; j < MAP_MAX_X; j++ ){
-			if( dun->map.obj.mjr[i][j]
-					== FACE_MJR_STAIRS_DOWN ){
-				flg_find = TRUE;
-				pty->square.x = j;
-				pty->square.y = i;
-				pty->square.pre_x = pty->square.x;
-				pty->square.pre_y = pty->square.y;
-				break;
-			}
-		}
-		if( flg_find ){
-			break;
-		}
-	}
-	if( !flg_find )
+	x = MAP_DEL_X;
+	y = MAP_DEL_Y;
+	if( !srch_map_obj( FACE_MJR_STAIRS_DOWN,
+			FACE_MNR_STAIRS_DOWN, &x, &y ) ){
 		return FALSE;
+	}
+	pty->square.x = x;
+	pty->square.y = y;
+	pty->square.pre_x = x;
+	pty->square.pre_y = y;
 
 	clr_map_all_mbr();
 	clr_map_all_pet();
@@ -1308,6 +1370,8 @@ bool_t	enter_shop( void )
 	clr_map_all_mbr();
 	clr_map_all_pet();
 
+	say_welcome_shop_msg( shop_n );
+
 	while( 1 ){
 		switch( face_mnr ){
 		case FACE_MNR_SHOP_INN:
@@ -1441,6 +1505,200 @@ void	party_exit_shop( long dr_n )
 
 /**/
 
+void	say_welcome_shop_msg( shop_n_t shop_n )
+{
+	sex_t	sex;
+	const char	*name;
+
+	sex = get_npc_sex_shop( shop_n );
+	name = get_npc_name_shop( shop_n, sex );
+
+	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
+		break;
+	case SHOP_N_INN:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_INN_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_INN_MALE );
+		break;
+	case SHOP_N_BAR:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_BAR_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_BAR_MALE );
+		break;
+	case SHOP_N_WPN:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_WPN_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_WPN_MALE );
+		break;
+	case SHOP_N_ARMOR:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_ARMOR_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_ARMOR_MALE );
+		break;
+	case SHOP_N_MAGIC:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_MAGIC_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_MAGIC_MALE );
+		break;
+	case SHOP_N_TEMPLE:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_TEMPLE_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_TEMPLE_MALE );
+		break;
+	case SHOP_N_ALCHEMY:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_ALCHEMY_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_ALCHEMY_MALE );
+		break;
+	case SHOP_N_MUSIC:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_MUSIC_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_MUSIC_MALE );
+		break;
+	case SHOP_N_GROCERY:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_GROCERY_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_GROCERY_MALE );
+		break;
+	case SHOP_N_RESTAURANT:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_RESTAURANT_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_RESTAURANT_MALE );
+		break;
+	case SHOP_N_TEAROOM:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_TEAROOM_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_TEAROOM_MALE );
+		break;
+	case SHOP_N_TOBACCO:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_TOBACCO_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_TOBACCO_MALE );
+		break;
+	case SHOP_N_PET_SHOP:
+		print_words( name, sex,
+				MSG_WORDS_WELCOME_SHOP_PET_SHOP_FEMALE,
+				MSG_WORDS_WELCOME_SHOP_PET_SHOP_MALE );
+		break;
+	}
+}
+
+/**/
+
+const char	*get_npc_name_shop( shop_n_t shop_n, sex_t sex )
+{
+	if( sex == FEMALE ){
+		switch( shop_n ){
+		case SHOP_N_NULL:
+		case SHOP_N_MAX_N:
+			return MSG_NPC_NAME_SHOP_NULL_FEMALE;
+		case SHOP_N_INN:
+			return MSG_NPC_NAME_SHOP_INN_FEMALE;
+		case SHOP_N_BAR:
+			return MSG_NPC_NAME_SHOP_BAR_FEMALE;
+		case SHOP_N_WPN:
+			return MSG_NPC_NAME_SHOP_WPN_FEMALE;
+		case SHOP_N_ARMOR:
+			return MSG_NPC_NAME_SHOP_ARMOR_FEMALE;
+		case SHOP_N_MAGIC:
+			return MSG_NPC_NAME_SHOP_MAGIC_FEMALE;
+		case SHOP_N_TEMPLE:
+			return MSG_NPC_NAME_SHOP_TEMPLE_FEMALE;
+		case SHOP_N_ALCHEMY:
+			return MSG_NPC_NAME_SHOP_ALCHEMY_FEMALE;
+		case SHOP_N_MUSIC:
+			return MSG_NPC_NAME_SHOP_MUSIC_FEMALE;
+		case SHOP_N_GROCERY:
+			return MSG_NPC_NAME_SHOP_GROCERY_FEMALE;
+		case SHOP_N_RESTAURANT:
+			return MSG_NPC_NAME_SHOP_RESTAURANT_FEMALE;
+		case SHOP_N_TEAROOM:
+			return MSG_NPC_NAME_SHOP_TEAROOM_FEMALE;
+		case SHOP_N_TOBACCO:
+			return MSG_NPC_NAME_SHOP_TOBACCO_FEMALE;
+		case SHOP_N_PET_SHOP:
+			return MSG_NPC_NAME_SHOP_PET_SHOP_FEMALE;
+		}
+	} else {
+		switch( shop_n ){
+		case SHOP_N_NULL:
+		case SHOP_N_MAX_N:
+			return MSG_NPC_NAME_SHOP_NULL_MALE;
+		case SHOP_N_INN:
+			return MSG_NPC_NAME_SHOP_INN_MALE;
+		case SHOP_N_BAR:
+			return MSG_NPC_NAME_SHOP_BAR_MALE;
+		case SHOP_N_WPN:
+			return MSG_NPC_NAME_SHOP_WPN_MALE;
+		case SHOP_N_ARMOR:
+			return MSG_NPC_NAME_SHOP_ARMOR_MALE;
+		case SHOP_N_MAGIC:
+			return MSG_NPC_NAME_SHOP_MAGIC_MALE;
+		case SHOP_N_TEMPLE:
+			return MSG_NPC_NAME_SHOP_TEMPLE_MALE;
+		case SHOP_N_ALCHEMY:
+			return MSG_NPC_NAME_SHOP_ALCHEMY_MALE;
+		case SHOP_N_MUSIC:
+			return MSG_NPC_NAME_SHOP_MUSIC_MALE;
+		case SHOP_N_GROCERY:
+			return MSG_NPC_NAME_SHOP_GROCERY_MALE;
+		case SHOP_N_RESTAURANT:
+			return MSG_NPC_NAME_SHOP_RESTAURANT_MALE;
+		case SHOP_N_TEAROOM:
+			return MSG_NPC_NAME_SHOP_TEAROOM_MALE;
+		case SHOP_N_TOBACCO:
+			return MSG_NPC_NAME_SHOP_TOBACCO_MALE;
+		case SHOP_N_PET_SHOP:
+			return MSG_NPC_NAME_SHOP_PET_SHOP_MALE;
+		}
+	}
+
+	return MSG_NPC_NAME_SHOP_NULL_MALE;
+}
+
+/**/
+
+sex_t	get_npc_sex_shop( shop_n_t shop_n )
+{
+	switch( shop_n ){
+	case SHOP_N_NULL:
+	case SHOP_N_MAX_N:
+		break;
+	case SHOP_N_INN:
+		return MALE;
+	case SHOP_N_BAR:
+		return MALE;
+	case SHOP_N_WPN:
+		return MALE;
+	case SHOP_N_ARMOR:
+		return MALE;
+	case SHOP_N_MAGIC:
+		return MALE;
+	case SHOP_N_TEMPLE:
+		return MALE;
+	case SHOP_N_ALCHEMY:
+		return FEMALE;
+	case SHOP_N_MUSIC:
+		return FEMALE;
+	case SHOP_N_GROCERY:
+		return MALE;
+	case SHOP_N_RESTAURANT:
+		return MALE;
+	case SHOP_N_TEAROOM:
+		return FEMALE;
+	case SHOP_N_TOBACCO:
+		return FEMALE;
+	case SHOP_N_PET_SHOP:
+		return FEMALE;
+	}
+
+	return MALE;
+}
+
+/**/
+
 void	party_enter_bar( void )
 {
 	door_t	*dr;
@@ -1617,8 +1875,10 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 
 		mbr = pty->mbr[i];
 
-		if( chk_flg_or( mbr->stat,
-				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+		if( chk_flg_or( mbr->stat, 0
+				| FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD
+				| FLG_STAT_STONE ) ){
 			continue;
 		}
 
@@ -1655,8 +1915,10 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 	for( i = 0; i < PET_MAX_N; i++ ){
 		if( pet[i] == NULL )
 			continue;
-		if( chk_flg_or( pet[i]->stat,
-				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+		if( chk_flg_or( pet[i]->stat, 0
+				| FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD
+				| FLG_STAT_STONE ) ){
 			continue;
 		}
 
@@ -1695,7 +1957,13 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 			get_calendar_str() );
 
 	if( chk_discount() ){
-		print_words( MSG_NPC_NAME_INN_LANDLORD, MALE,
+		sex_t	sex;
+		const char	*name;
+
+		sex = get_npc_sex_shop( SHOP_N_INN );
+		name = get_npc_name_shop( SHOP_N_INN, sex );
+
+		print_words( name, sex,
 				MSG_WORDS_DISCOUNT_DAY_FEMALE,
 				MSG_WORDS_DISCOUNT_DAY_MALE,
 				get_shop_name( g_discount_queue.shop_n ) );
